from azure.graphrbac import GraphRbacManagementClient
from azure.common.credentials import ServicePrincipalCredentials
from typing import List
from ..records import AzureClient
from .. import exceptions
from .records import GroupData, Group, User, UserData


def process_groups(groups: list) -> List[Group]:
    return [GroupData(**group.as_dict()).__dict__ for group in groups]


def process_users(users: list) -> List[User]:
    return [UserData(**user.as_dict()).__dict__ for user in users]


def client(client: AzureClient) -> GraphRbacManagementClient:
    if missing_keys := [key for key in client if key not in {"client_id", "client_secret", "tenant_id"}]:
        raise exceptions.MissingApiSecret(f"The following keys are missing from azure_client: '{missing_keys}'")

    credential = ServicePrincipalCredentials(
        client_id=client["client_id"],
        secret=client["client_secret"],
        tenant=client["tenant_id"],
        resource="https://graph.windows.net",
    )

    return GraphRbacManagementClient(credential, client["tenant_id"])
