from azure.mgmt.compute import ComputeManagementClient
from azure.common.credentials import ServicePrincipalCredentials
from typing import List
from .records import VirtualMachineData, VirtualMachine
from .. import exceptions
from ..records import AzureClient


def process_virtual_machines(response: list) -> List[VirtualMachine]:
    return [VirtualMachineData(**instance.as_dict()).__dict__ for instance in response]


def client(client: AzureClient, subscription_id: str) -> ComputeManagementClient:
    if missing_keys := [key for key in client if key not in {"client_id", "client_secret", "tenant_id"}]:
        raise exceptions.MissingApiSecret(f"The following keys are missing from azure_client: '{missing_keys}'")

    credential = ServicePrincipalCredentials(
        client_id=client["client_id"], secret=client["client_secret"], tenant=client["tenant_id"]
    )
    return ComputeManagementClient(credential, subscription_id)
